@@ -1,6 +1,7 @@
 from django.contrib import admin
-from .models import SyncedCharacter, SyncManager
+
 from . import tasks
+from .models import SyncedCharacter, SyncManager
 
 
 @admin.register(SyncedCharacter)
@@ -9,6 +10,7 @@ class SyncedCharacterAdmin(admin.ModelAdmin):
         "user",
         "character_name",
         "version_hash",
+        "_sync_ok",
         "last_sync",
         "last_error",
         "manager",
@@ -17,25 +19,27 @@ class SyncedCharacterAdmin(admin.ModelAdmin):
         "last_error",
         "version_hash",
         "last_sync",
-        "character__user",
+        "character_ownership__user",
         "manager",
     )
     actions = ["start_sync_contacts"]
-
     list_display_links = None
 
+    def _sync_ok(self, obj) -> bool:
+        return obj.is_sync_ok
+
+    _sync_ok.boolean = True
+
+    def has_add_permission(self, request):
+        return False
+
     def user(self, obj):
-        return obj.character.user
+        return obj.character_ownership.user
 
     def character_name(self, obj):
         return obj.__str__()
 
-    # This will help you to disbale add functionality
-    def has_add_permission(self, request):
-        return False
-
     def start_sync_contacts(self, request, queryset):
-
         names = list()
         for obj in queryset:
             tasks.run_character_sync.delay(sync_char_pk=obj.pk, force_sync=True)
@@ -55,16 +59,23 @@ class SyncManagerAdmin(admin.ModelAdmin):
         "user",
         "character_name",
         "version_hash",
+        "_sync_ok",
         "last_sync",
         "last_error",
     )
-
     list_display_links = None
-
     actions = ["start_sync_managers"]
 
+    def _sync_ok(self, obj) -> bool:
+        return obj.is_sync_ok
+
+    _sync_ok.boolean = True
+
+    def has_add_permission(self, request):
+        return False
+
     def user(self, obj):
-        return obj.character.user if obj.character else None
+        return obj.character_ownership.user if obj.character_ownership else None
 
     def character_name(self, obj):
         return obj.__str__()
@@ -73,27 +84,18 @@ class SyncManagerAdmin(admin.ModelAdmin):
         return obj.alliance.alliance_name
 
     def contacts_count(self, obj):
-        return "{:,}".format(obj.alliancecontact_set.count())
+        return "{:,}".format(obj.contacts.count())
 
     def synced_characters_count(self, obj):
-        return "{:,}".format(obj.syncedcharacter_set.count())
-
-    # This will help you to disbale add functionality
-    def has_add_permission(self, request):
-        return False
+        return "{:,}".format(obj.synced_characters.count())
 
     def start_sync_managers(self, request, queryset):
-
         names = list()
         for obj in queryset:
-            tasks.run_manager_sync.delay(
-                manager_pk=obj.pk, force_sync=True, user_pk=request.user.pk
-            )
+            tasks.run_manager_sync.delay(manager_pk=obj.pk, force_sync=True)
             names.append(str(obj))
 
         text = "Started syncing for: {} ".format(", ".join(names))
-        text += "You will receive a report once it is completed."
-
         self.message_user(request, text)
 
     start_sync_managers.short_description = "Sync selected managers"
